@@ -36,13 +36,13 @@ use vars qw(
     $SCRIPT $VERSION $DATE $NAME_SHORT $NAME_ARTICLE $BASIC_NAME $BASIC_ARTICLE $BASIC_VERSION
     $AUTHORS $COPYRIGHT $URL $NAME_FILE @COMPAT_FILE_LIST @COMPAT_DIR_LIST @COMPAT_EXT_LIST
     $BLIND_MODE_FLAG $SAFE_MODE_FLAG $TEST_MODE_FLAG @TEST_MODE_LOGIN_LIST $TEST_MODE_CMD_FLAG
-    $TEST_TERM_MODE_FLAG $TEST_GLOB_MODE_FLAG @LICENSE_LIST @CREDIT_LIST $SHARE_DIR $DATA_DIR
-    $CLIENT
+    $TEST_TERM_MODE_FLAG $TEST_GLOB_MODE_FLAG $TEST_PRE_CONFIG_FLAG @LICENSE_LIST @CREDIT_LIST
+    $SHARE_DIR $DATA_DIR $CLIENT
 );
 
 $SCRIPT = 'Axmud';              # Name used in system messages
-$VERSION = '1.1.012';           # Version number for this client
-$DATE = '8 Jun 2018';
+$VERSION = '1.1.050';           # Version number for this client
+$DATE = '31 Jul 2018';
 $NAME_SHORT = 'axmud';          # Lower-case version of $SCRIPT; same as the package name above
 $NAME_ARTICLE = 'an Axmud';     # Name with an article
 $BASIC_NAME = 'Axbasic';        # Name of Axmud's built-in scripting library
@@ -89,6 +89,9 @@ $TEST_TERM_MODE_FLAG = FALSE;
 #   operation (not including the config file) tests data for this problem, before saving it, writing
 #   the output to the terminal
 $TEST_GLOB_MODE_FLAG = FALSE;
+# Pre-configured world test mode: When preparing for a release, the authors set this flag to TRUE to
+#   stop Axmud complaining about missing pre-configured worlds
+$TEST_PRE_CONFIG_FLAG = FALSE;
 
 @LICENSE_LIST = (
     'This program is free software; you can redistribute it and/or modify it under',
@@ -125,6 +128,7 @@ $TEST_GLOB_MODE_FLAG = FALSE;
 # External dependencies (Glib is commented out as it's already been used)
 use Archive::Extract;
 use Archive::Tar;
+use Archive::Zip;
 use Compress::Zlib;
 use Encode qw(decode encode encodings find_encoding from_to);
 use Fcntl qw(:flock);
@@ -163,6 +167,7 @@ use Socket qw(AF_INET SOCK_STREAM inet_aton sockaddr_in);
 use Symbol qw(qualify);
 use Storable qw(lock_nstore lock_retrieve);
 use Time::HiRes qw(gettimeofday);
+use Time::Piece;
 
 # Internal dependencies
 use Games::Axmud;
@@ -184,17 +189,6 @@ push (@INC,
     $SHARE_DIR . '/private',
 );
 
-# Create the main GA::Client object
-$CLIENT = Games::Axmud::Client->new();
-# Start the client. If this fails, terminate the script
-if (! $CLIENT || ! $CLIENT->start()) {
-
-    exit 1;
-}
-
-# Start Gtk2's main loop
-Gtk2->main();
-
 # Standard Perl error/warning trapping
 $SIG{__DIE__} = sub {
 
@@ -253,6 +247,17 @@ $SIG{__WARN__} = sub {
     }
 };
 
+# Create the main GA::Client object
+$CLIENT = Games::Axmud::Client->new();
+# Start the client. If this fails, terminate the script
+if (! $CLIENT || ! $CLIENT->start()) {
+
+    exit 1;
+}
+
+# Start Gtk2's main loop
+Gtk2->main();
+
 END {
 
     # Stop the client - unless the GA::Client->stop() function has already been called
